View Source Rag.Evaluation.OpenAI (rag v0.1.0)

Evaluation for RAG systems using the OpenAI API.

Summary

Functions

Evaluates the response, query, and context according to the RAG triad.

Functions

evaluate_rag_triad(generation, openai_params)

Evaluates the response, query, and context according to the RAG triad.

  • context relevance: is the retrieved context relevant to the query?
  • groundedness: is the response supported by the context?
  • answer relevance: is the answer relevant to the query?

Prompts from https://github.com/truera/trulens/blob/main/src/feedback/trulens/feedback/prompts.py